% Elaborato di Robotica Industriale - prof G.A. Magnani
% M. Gritti e W. Spinelli
%
% MATLAB Function che descrive la dinamica del robot planare a 2 link
%
%  y = acceler(u)
%
% Parametri della Function
%

% Ingressi
% u(1) = dq1      : Velocit?del link 1
% u(2) = q1       : Posizione del link 1
% u(3) = taull1   : Coppia applicata al link 1
% u(4) = taull2   : Coppia applicata al link 2
% u(5) = q2       : Posizione del link 2
% u(6) = dq2      : Velocit?del link 2
%
% Uscite
% y(1)            : Accelerazione del link 1
% y(2)            : Accelerazione del link 2


function y = acceler(u)
% Definizione delle corrispondenze con gli ingressi
dq1    = u(1);       % Velocit?del link 1
q1     = u(2);       % Posizione del link 1
taull1 = u(3);       % Coppia applicata al link 1
dq2    = u(6);       % Velocit?del link 2
q2     = u(5);       % Posizione del link 2
taull2 = u(4);       % Coppia applicata al link 2

m1     = u(7);       % Massa del link 1
m2     = u(8);       % Massa del link 2
a      = u(9);       % Lunghezza dei link (supposti uguali)
g      = u(10);      % Accelerazione di gravit?


% Calcolo dei seni e coseni degli angoli
c1  = cos(q1);
c2  = cos(q2);
s2  = sin(q2);
c12 = cos(q1 + q2);

% Matrice d'inerzia
B = a^2 * [(1/3*m1 + 4/3*m2 + m2*c2)      (1/3*m2 + 1/2*m2*c2);...
           (1/3*m2 + 1/2*m2*c2)           (1/3*m2)            ];

% Matrice dei termini gravitazionali
G = g * a * [ (1/2*m1*c1 + 1/2*m2*c12 + m2*c1);...
              (1/2*m2*c12)                    ];

% Matrice dei termini centrifughi e di Coriolis
C = a^2 * [ -(1/2*m2*s2*dq2^2 + m2*s2*dq1*dq2);...
              1/2*m2*s2*dq1^2                 ];

% Calcolo delle accelerazioni
y = inv(B) * ([taull1; taull2] - C - G);